@@ -1,4 +1,4 @@
-# $Id: go_def.pm,v 1.2 2004/03/19 01:42:18 cmungall Exp $
+# $Id: go_def.pm,v 1.3 2005/03/22 04:51:08 cmungall Exp $
 #
 # This GO module is maintained by Chris Mungall <cjm@fruitfly.org>
 #
@@ -26,6 +26,8 @@
 # makes objects from parser events
 
 package GO::Handlers::go_def;
+use GO::Parsers::ParserEventNames;
+use Data::Stag qw(:all);
 use base qw(GO::Handlers::base);
 use strict;
 
@@ -33,14 +35,14 @@ use strict;
 sub e_term {
     my $self = shift;
     my $t = shift;
-    my $n = $t->get_name || '';
-    my $def = $t->get_definition;
+    my $n = stag_get($t, NAME);
+    my $def = stag_get($t, DEF);
     if ($def) {
         $self->tag(term => $n);
-        $self->tag(goid => $t->get_id);
-        $self->tag(definition => $def->sget_definition_text);
-        $self->tag(definition_reference => $_) foreach $def->get_definition_reference;
-        $self->tag(comment => $def->sget_comment);
+        $self->tag(goid => stag_sget($t, ID));
+        $self->tag(definition => stag_sget($def, DEFSTR));
+        $self->tag(definition_reference => stag_sget($_,DBNAME).':'.stag_sget($_,ACC)) foreach stag_get($def, DBXREF);
+        $self->tag(comment => stag_sget($t, COMMENT));
 
         $self->print("\n");
     }
@@ -53,25 +55,8 @@ sub tag {
     my ($t, $v) = @_;
     return unless $v;
     $self->printf("%s: %s\n", $t, $v);
-#    $self->print("$t: $v\n");
+    return;
 }
 
-sub safe {
-    my $word = shift;
-    $word =~ s/ /_/g;
-    $word =~ s/\-/_/g;
-    $word =~ s/\'/prime/g;
-    $word =~ tr/a-zA-Z0-9_//cd;
-    $word =~ s/^([0-9])/_$1/;
-    $word;
-}
-
-sub quote {
-    my $word = shift;
-    $word =~ s/\'//g;
-    $word =~ s/\"/\\\"/g;
-    $word =~ tr/a-zA-Z0-9_//cd;
-    "\"$word\"";
-}
 
 1;
